package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcPostSalaryMapper;
import com.ruoyi.common.core.domain.entity.CmcPostSalary;
import com.ruoyi.oa.service.ICmcPostSalaryService;

/**
 * cmc岗位工资Service业务层处理
 * 
 * @author cmc
 * @date 2024-03-25
 */
@Service
public class CmcPostSalaryServiceImpl implements ICmcPostSalaryService 
{
    @Autowired
    private CmcPostSalaryMapper cmcPostSalaryMapper;

    /**
     * 查询cmc岗位工资
     * 
     * @param salaryId cmc岗位工资主键
     * @return cmc岗位工资
     */
    @Override
    public CmcPostSalary selectCmcPostSalaryBySalaryId(Integer salaryId)
    {
        return cmcPostSalaryMapper.selectCmcPostSalaryBySalaryId(salaryId);
    }

    /**
     * 查询cmc岗位工资列表
     * 
     * @param cmcPostSalary cmc岗位工资
     * @return cmc岗位工资
     */
    @Override
    public List<CmcPostSalary> selectCmcPostSalaryList(CmcPostSalary cmcPostSalary)
    {
        return cmcPostSalaryMapper.selectCmcPostSalaryList(cmcPostSalary);
    }

    /**
     * 新增cmc岗位工资
     * 
     * @param cmcPostSalary cmc岗位工资
     * @return 结果
     */
    @Override
    public int insertCmcPostSalary(CmcPostSalary cmcPostSalary)
    {
        return cmcPostSalaryMapper.insertCmcPostSalary(cmcPostSalary);
    }

    /**
     * 修改cmc岗位工资
     * 
     * @param cmcPostSalary cmc岗位工资
     * @return 结果
     */
    @Override
    public int updateCmcPostSalary(CmcPostSalary cmcPostSalary)
    {
        return cmcPostSalaryMapper.updateCmcPostSalary(cmcPostSalary);
    }

    /**
     * 批量删除cmc岗位工资
     * 
     * @param salaryIds 需要删除的cmc岗位工资主键
     * @return 结果
     */
    @Override
    public int deleteCmcPostSalaryBySalaryIds(Integer[] salaryIds)
    {
        return cmcPostSalaryMapper.deleteCmcPostSalaryBySalaryIds(salaryIds);
    }

    /**
     * 删除cmc岗位工资信息
     * 
     * @param salaryId cmc岗位工资主键
     * @return 结果
     */
    @Override
    public int deleteCmcPostSalaryBySalaryId(Integer salaryId)
    {
        return cmcPostSalaryMapper.deleteCmcPostSalaryBySalaryId(salaryId);
    }
}
